MessageData class

Inheritance
  • Object
  • GeneratedMessage
  • MessageData

Constructors

MessageData()
factory
MessageData.fromBuffer(List<int> i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory
MessageData.fromJson(String i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory

Properties

castAddBody ↔ CastAddBody
getter/setter pair
castRemoveBody ↔ CastRemoveBody
getter/setter pair
eventPlugin → EventPlugin?
Subclasses can override this getter to be notified of changes to protobuf fields.
no setterinherited
fid ↔ Int64
getter/setter pair
hashCode → int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setteroverride
isFrozen → bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
linkBody ↔ LinkBody
getter/setter pair
network ↔ FarcasterNetwork
getter/setter pair
reactionBody ↔ ReactionBody
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signerAddBody ↔ SignerAddBody
getter/setter pair
signerRemoveBody ↔ SignerRemoveBody
getter/setter pair
timestamp ↔ int
getter/setter pair
type ↔ MessageType
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited
userDataBody ↔ UserDataBody
getter/setter pair
usernameProofBody ↔ UserNameProof
getter/setter pair
verificationAddEthAddressBody ↔ VerificationAddEthAddressBody
getter/setter pair
verificationRemoveBody ↔ VerificationRemoveBody
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearBody() → void
clearCastAddBody() → void
clearCastRemoveBody() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearFid() → void
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearLinkBody() → void
clearNetwork() → void
clearReactionBody() → void
clearSignerAddBody() → void
clearSignerRemoveBody() → void
clearTimestamp() → void
clearType() → void
clearUserDataBody() → void
clearUsernameProofBody() → void
clearVerificationAddEthAddressBody() → void
clearVerificationRemoveBody() → void
clone() → MessageData
Creates a deep copy of the fields in this message. (The generated code uses mergeFromMessage.)
override
copyWith(void updates(MessageData)) → MessageData
Apply updates to a copy of this message.
override
createEmptyInstance() → MessageData
Creates an empty instance of the same message type as this.
override
createMapField<K, V>(int tagNumber, MapFieldInfo<K, V> fi) → Map<K, V>
Creates a Map representing a map field.
inherited
createRepeatedField<T>(int tagNumber, FieldInfo<T> fi) → List<T>
Creates List implementing a mutable repeated field.
inherited
ensureCastAddBody() → CastAddBody
ensureCastRemoveBody() → CastRemoveBody
ensureLinkBody() → LinkBody
ensureReactionBody() → ReactionBody
ensureSignerAddBody() → SignerAddBody
ensureSignerRemoveBody() → SignerRemoveBody
ensureUserDataBody() → UserDataBody
ensureUsernameProofBody() → UserNameProof
ensureVerificationAddEthAddressBody() → VerificationAddEthAddressBody
ensureVerificationRemoveBody() → VerificationRemoveBody
extensionsAreInitialized() → bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) → int?
inherited
hasCastAddBody() → bool
hasCastRemoveBody() → bool
hasExtension(Extension extension) → bool
Returns true if a value of extension is present.
inherited
hasFid() → bool
hasField(int tagNumber) → bool
Whether this message has a field associated with tagNumber.
inherited
hasLinkBody() → bool
hasNetwork() → bool
hasReactionBody() → bool
hasRequiredFields() → bool
Whether the message has required fields.
inherited
hasSignerAddBody() → bool
hasSignerRemoveBody() → bool
hasTimestamp() → bool
hasType() → bool
hasUserDataBody() → bool
hasUsernameProofBody() → bool
hasVerificationAddEthAddressBody() → bool
hasVerificationRemoveBody() → bool
isInitialized() → bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() → String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() → String
Returns a String representation of this message.
inherited
whichBody() → MessageData_Body
writeToBuffer() → Uint8List
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
inherited
writeToJson() → String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() → Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

create() → MessageData
createRepeated() → PbList<MessageData>
getDefault() → MessageData